!--------------------- BEGIN saprc99_parameters.f90 BEGIN --------------------
! @file saprc99_parameters.f90                                                
! @author jlinford                                                            
! @date 2017-02-27 19:38:46.287540                                            
! @brief Program parameters                                                   
!                                                                             
! Integration tolerances, program constants, and species indices.             
!                                                                             
! This file was generated by Kppa: http://www.paratools.com/Kppa              
!-----------------------------------------------------------------------------


MODULE saprc99_parameters


  IMPLICIT NONE



!-----------------------------------------------------------------------------
! Integration tolerances                                                      
!-----------------------------------------------------------------------------

  ! Absolute tolerance 
  REAL(8), PARAMETER :: ATOLS = 1.0d-3
  ! Relative tolerance 
  REAL(8), PARAMETER :: RTOLS = 1.0d-4


!-----------------------------------------------------------------------------
! Concentration constants                                                     
!-----------------------------------------------------------------------------

  ! Conversion factor 
  REAL(8), PARAMETER :: CFACTOR = 2.4476e+13
  ! Default initialization value for variable species 
  REAL(8), PARAMETER :: VAR_DEFAULT = 0.0
  ! Default initialization value for fixed species 
  REAL(8), PARAMETER :: FIX_DEFAULT = 0.0


!-----------------------------------------------------------------------------
! Program constants                                                           
!-----------------------------------------------------------------------------

  ! Species count 
  INTEGER, PARAMETER :: NSPEC = 79
  ! Variable species count 
  INTEGER, PARAMETER :: NVAR = 74
  ! Fixed species count 
  INTEGER, PARAMETER :: NFIX = 5
  ! Active variable species count 
  INTEGER, PARAMETER :: NVARACT = 66
  ! Reaction (equation) count 
  INTEGER, PARAMETER :: NREACT = 211


!-----------------------------------------------------------------------------
! Numerical constants                                                         
!-----------------------------------------------------------------------------

  REAL(8), PARAMETER :: ZERO = 0.0
  REAL(8), PARAMETER :: HALF = 0.5
  REAL(8), PARAMETER :: ONE = 1.0
  REAL(8), PARAMETER :: TWO = 2.0


!-----------------------------------------------------------------------------
! Variable species indices                                                    
!-----------------------------------------------------------------------------

  INTEGER, PARAMETER :: IND_H2SO4 = 1
  INTEGER, PARAMETER :: IND_HCOOH = 2
  INTEGER, PARAMETER :: IND_CCO_OH = 3
  INTEGER, PARAMETER :: IND_RCO_OH = 4
  INTEGER, PARAMETER :: IND_CCO_OOH = 5
  INTEGER, PARAMETER :: IND_RCO_OOH = 6
  INTEGER, PARAMETER :: IND_XN = 7
  INTEGER, PARAMETER :: IND_XC = 8
  INTEGER, PARAMETER :: IND_SO2 = 9
  INTEGER, PARAMETER :: IND_O1D = 10
  INTEGER, PARAMETER :: IND_ALK1 = 11
  INTEGER, PARAMETER :: IND_BACL = 12
  INTEGER, PARAMETER :: IND_PAN = 13
  INTEGER, PARAMETER :: IND_PAN2 = 14
  INTEGER, PARAMETER :: IND_PBZN = 15
  INTEGER, PARAMETER :: IND_MA_PAN = 16
  INTEGER, PARAMETER :: IND_H2O2 = 17
  INTEGER, PARAMETER :: IND_N2O5 = 18
  INTEGER, PARAMETER :: IND_HONO = 19
  INTEGER, PARAMETER :: IND_ALK2 = 20
  INTEGER, PARAMETER :: IND_ALK3 = 21
  INTEGER, PARAMETER :: IND_TBU_O = 22
  INTEGER, PARAMETER :: IND_ALK5 = 23
  INTEGER, PARAMETER :: IND_ARO2 = 24
  INTEGER, PARAMETER :: IND_HNO4 = 25
  INTEGER, PARAMETER :: IND_COOH = 26
  INTEGER, PARAMETER :: IND_HOCOO = 27
  INTEGER, PARAMETER :: IND_BZNO2_O = 28
  INTEGER, PARAMETER :: IND_MEOH = 29
  INTEGER, PARAMETER :: IND_ALK4 = 30
  INTEGER, PARAMETER :: IND_ARO1 = 31
  INTEGER, PARAMETER :: IND_DCB2 = 32
  INTEGER, PARAMETER :: IND_DCB3 = 33
  INTEGER, PARAMETER :: IND_CRES = 34
  INTEGER, PARAMETER :: IND_DCB1 = 35
  INTEGER, PARAMETER :: IND_NPHE = 36
  INTEGER, PARAMETER :: IND_ROOH = 37
  INTEGER, PARAMETER :: IND_BALD = 38
  INTEGER, PARAMETER :: IND_PHEN = 39
  INTEGER, PARAMETER :: IND_CO = 40
  INTEGER, PARAMETER :: IND_MGLY = 41
  INTEGER, PARAMETER :: IND_ACET = 42
  INTEGER, PARAMETER :: IND_HNO3 = 43
  INTEGER, PARAMETER :: IND_ETHENE = 44
  INTEGER, PARAMETER :: IND_GLY = 45
  INTEGER, PARAMETER :: IND_BZ_O = 46
  INTEGER, PARAMETER :: IND_ISOPRENE = 47
  INTEGER, PARAMETER :: IND_R2O2 = 48
  INTEGER, PARAMETER :: IND_TERP = 49
  INTEGER, PARAMETER :: IND_METHACRO = 50
  INTEGER, PARAMETER :: IND_OLE1 = 51
  INTEGER, PARAMETER :: IND_ISOPROD = 52
  INTEGER, PARAMETER :: IND_OLE2 = 53
  INTEGER, PARAMETER :: IND_MVK = 54
  INTEGER, PARAMETER :: IND_CCHO = 55
  INTEGER, PARAMETER :: IND_HCHO = 56
  INTEGER, PARAMETER :: IND_RNO3 = 57
  INTEGER, PARAMETER :: IND_O3P = 58
  INTEGER, PARAMETER :: IND_RCHO = 59
  INTEGER, PARAMETER :: IND_MEK = 60
  INTEGER, PARAMETER :: IND_PROD2 = 61
  INTEGER, PARAMETER :: IND_O3 = 62
  INTEGER, PARAMETER :: IND_HO2 = 63
  INTEGER, PARAMETER :: IND_RO2_N = 64
  INTEGER, PARAMETER :: IND_MA_RCO3 = 65
  INTEGER, PARAMETER :: IND_C_O2 = 66
  INTEGER, PARAMETER :: IND_BZCO_O2 = 67
  INTEGER, PARAMETER :: IND_RO2_R = 68
  INTEGER, PARAMETER :: IND_NO = 69
  INTEGER, PARAMETER :: IND_NO2 = 70
  INTEGER, PARAMETER :: IND_NO3 = 71
  INTEGER, PARAMETER :: IND_CCO_O2 = 72
  INTEGER, PARAMETER :: IND_RCO_O2 = 73
  INTEGER, PARAMETER :: IND_OH = 74


!-----------------------------------------------------------------------------
! Fixed species indices                                                       
!-----------------------------------------------------------------------------

  INTEGER, PARAMETER :: IND_AIR = 75
  INTEGER, PARAMETER :: IND_O2 = 76
  INTEGER, PARAMETER :: IND_H2O = 77
  INTEGER, PARAMETER :: IND_H2 = 78
  INTEGER, PARAMETER :: IND_CH4 = 79


END MODULE saprc99_parameters
!----------------------- END saprc99_parameters.f90 END ----------------------
